<?php
/**
 * An interface for registries
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2013 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface Register extends FrameworkInterface {
	/**
	 * Checks whether an instance key was found
	 *
	 * @param	$instanceKey	The key holding an instance in registry
	 * @return	$exists			Whether the key exists in registry
	 */
	function instanceExists ($instanceKey);

	/**
	 * Adds/overwrites a new instance to the registry at the given key
	 *
	 * @param	$instanceKey		The key to identify the instance
	 * @param	$objectInstance		An instance we shall store
	 * @return	void
	 */
	function addInstance ($instanceKey, Registerable $objectInstance);

	/**
	 * Gets a registered instance or null if not found
	 *
	 * @param	$instanceKey		The key to identify the instance
	 * @return	$objectInstance		An instance we shall store
	 */
	function getInstance ($instanceKey);
}

// [EOF]
?>
